#	=================================================================================================================================================================
#	=================================================================================================================================================================

#	PROJECT: EMCDDA CUD Treatment
# CODE AUTHOR: Jakob Manthey

rm(list = ls())
DATE 	<- "231205"

setwd("C:/Data.work/Publications/EAPC_cannabis special issue/CUD treatment demand/data") 

#	LIBRARIES:
#	.....................

library( data.table )
library( ggplot2 )
library( ggthemes )
library( openxlsx )
library( Hmisc )

#	LOAD DATA:
#	.....................

##  Population [UN] in 1,000s
pop.dat <- data.table(read.csv("prepared data/input_population.csv"))  
pop.dat[, pop := pop*1000] # to have pop on original scale

##  TDI trend any drug
dat.trend.any <- data.table(read.csv("prepared data/input_Treatment numbers trend_any drug.csv"))
dat.trend.any$country <- gsub(" \\*", "", dat.trend.any$country)

##  TDI trend cannabis
dat.trend.cannabis <- data.table(read.csv("prepared data/input_Treatment numbers trend_cannabis.csv"))
dat.trend.cannabis$country <- gsub(" \\*", "", dat.trend.cannabis$country)

##  (near) daily cannabis use prevalence
dat.prev.cannabis <- data.table(read.csv("prepared data/input_daily use.csv"))
dat.prev.cannabis$country <- gsub(" \\*", "", dat.prev.cannabis$country)

##  treatment referal 
dat.referal <- data.table(read.csv("prepared data/input_TDI by referral.csv"))
dat.referal$country <- gsub(" \\*", "", dat.referal$country)


#	=================================================================================================================================================================
#	=================================================================================================================================================================
#	=================================================================================================================================================================

#	1) PREPARE TREND DATA:
#	.....................

## Any and cannabis admissions
data <- merge(dat.trend.any,dat.trend.cannabis, by = c("country","year","sex"))
data[, .N, country]
data[, catf := admissions_cannabis/admissions_any.drug]

#	2) PREPARE DATA FOR CATF:
#	.....................

dat.catf <- copy(data)

##  SELECT COMMON COUNTRIES FOR CATF ANALYSES
dat.catf <- copy(dat.catf[!is.na(catf),.(country,year,sex,any = admissions_any.drug, cannabis = admissions_cannabis)])
dat.catf[, .(n.countries = .N, any = sum(any), cannabis = sum(any)),
     by = .(year,sex)][order(sex,year)]

  # select countries with consistent data in core period 2013-2020:
  n.sel <- 8
  select.men <- dat.catf[sex == "men" & year %between% c(2013,2020), .N, by = country][N==n.sel]$country
  select.women <- dat.catf[sex == "women" & year %between% c(2013,2020), .N, by = country][N==n.sel]$country
  select.total <- dat.catf[sex == "total" & year %between% c(2013,2020), .N, by = country][N==n.sel]$country
  all(select.women == select.men) # ok
  all(select.women == select.total) # ok
  
  dat.catf <- dat.catf[year %between% c(2013,2020) & 
                         ((sex == "men" & country %in% select.men) | 
                            (sex == "women" & country %in% select.women) |
                            (sex == "total" & country %in% select.total))]
  dat.catf[, .N, by = .(sex,country)] # should be all 8
  dat.catf[, .N, by = .(sex)] # 160 / 8 years = 20 countries
  rm(select.men,select.women,select.total)
  
  ##  problem Sweden 2013:
  ggplot(dat.catf[country == "Sweden"], aes(x = year, color = sex)) +
    geom_line(aes(y = any), linetype = 2) + 
    geom_line(aes(y = cannabis), linetype = 1) + 
    scale_x_continuous(breaks = c(2013:2021)) # implausible data for all-cause entries in 2013
  dat.catf[year == 2013 & country == "Sweden"] # ==> remove because of implausible data ==> 21 countries
  dat.catf <- dat.catf[country != "Sweden"]
  
  # check the % of admissions in 2020 being included:
  dat.trend.cannabis[year == 2020 & sex == "men" & country %in% unique(dat.catf[sex == "men"]$country), sum(admissions_cannabis)] /
    dat.trend.cannabis[year == 2020 & sex == "men", sum(admissions_cannabis, na.rm = T)] # men: 90%
  dat.trend.cannabis[year == 2020 & sex == "women" & country %in% unique(dat.catf[sex == "women"]$country), sum(admissions_cannabis)] /
    dat.trend.cannabis[year == 2020 & sex == "women", sum(admissions_cannabis, na.rm = T)] # women: 88%
  dat.trend.cannabis[year == 2020 & sex == "total" & country %in% unique(dat.catf[sex == "total"]$country), sum(admissions_cannabis)] /
    dat.trend.cannabis[year == 2020 & sex == "total", sum(admissions_cannabis, na.rm = T)] # total: 90%
    
  # get cannabis share
  dat.catf[, catf := cannabis/any]
  dat.catf[catf > 1] # none
  

#	3) PREPARE DATA FOR TUR:
#	.....................

##  COMBINE TDI AND NEAR DAILY CANNABIS USE PREVALENCE
dat.tur <- dat.trend.cannabis[sex == "total",.(country,year,tdi = admissions_cannabis)][order(country,year)]
unique(dat.tur$country[!dat.tur$country %in% dat.prev.cannabis$country]) # no data on daily use % from Estonia Malta Sweden Turkey
dat.tur <- merge(dat.tur, dat.prev.cannabis, by = c("country","year"), all.x = T)
dat.tur[, .N, by =.(country,year)][N>1] # none !!

##  ADD POPULATION
dat.tur <- merge(dat.tur, pop.dat[,.(country,year,age,pop)], by = c("country","year","age"))

##  Keep first and last year with full data
dat.tur <- dat.tur[complete.cases(dat.tur)]
dat.tur[, first := min(year), by = country]
dat.tur[, last := max(year), by = country]
dat.tur <- dat.tur[year == first | year == last]

##  remove countries where pm.daily == 0
dat.tur <- dat.tur[pm.daily > 0]

##  mark countries with only one data point!
select <- dat.tur[,.N, by = country][N == 1]$country # Bulgaria, Greece, Ireland, Luxemburg, Netherlands, Slovakia
dat.tur[, year.one := country %in% select]

nrow(dat.tur) # 46 rows
dat.tur[, length(unique(country))] # 26 countries
dat.tur[year.one == F, length(unique(country))] # 20 countries with two data points

##  TUR = treatment-user-ratio = treatment entries per 100 (near) daily users
dat.tur[, tur := (tdi / (pm.daily*pop))*100]


#	4) GET COMBINED DATA:
#	.....................

## CATF + TUR
data <- merge(data,dat.tur[,.(country,year,sex = "total",pm.daily,pop,tur)], by = c("country","year","sex"), all = T)
data[, .N, country]

#	=================================================================================================================================================================
#	=================================================================================================================================================================
#	=================================================================================================================================================================

#	RESULTS SECTION:
#	.....................

# 1) CATF
# ________________________

# in last available year: see figure

# admissions over time
dat.catf[sex == "total", sum(any), by = year]
dat.catf[sex == "total", .(sum(any), sum(cannabis)), by = year][,V2/V1]
dat.catf[sex == "total", wtd.mean(catf,any), by = year]
dat.catf[sex != "total", wtd.mean(catf,any), by = .(sex,year)][order(sex,year)]


# 2) TUR
# ________________________

# show years:
summary(dat.tur[year.one == F & year != last]$year) # first year
summary(dat.tur[year == last]$year) # last year

# get median
summary(dat.tur[year.one == F & year != last]$year) # first year
summary(dat.tur[year == last]$year) # last year

# get total number of admissions at last 



#	=================================================================================================================================================================
#	=================================================================================================================================================================
#	=================================================================================================================================================================

#	TABLES:
#	.....................

# Table 1:
# ________________________

tab.dat <- copy(dat.catf[sex != "total", .(any = sum(any),
                             cannabis = sum(cannabis),
                             catf = wtd.mean(catf, any)), by = .(year,sex)])[order(sex,year)]
write.xlsx(tab.dat, paste0("tables/",DATE,"_T1.xlsx"))
unique(dat.catf$country)


#	=================================================================================================================================================================
#	=================================================================================================================================================================
#	=================================================================================================================================================================

#	FIGURES:
#	.....................

##  THEME
theme_set( theme_gdocs() )
options(scipen = 999)

# FIGURE 1: CATF by country
# ________________________

pdat <- copy(data[!is.na(catf) & sex == "total",.(country,year,admissions_any.drug,admissions_cannabis,catf)])
pdat[, last.year := max(year), by = country]
pdat <- pdat[year == last.year,.(country,year,admissions_any.drug,admissions_cannabis,catf)]
add <- pdat[, .(country = "EUROPE", year = 2021,
                admissions_any.drug = sum(admissions_any.drug), 
                admissions_cannabis = sum(admissions_cannabis),
                catf = wtd.mean(catf,admissions_any.drug))]
pdat <- rbind(pdat,add)[order(catf)]
pdat[, EU := country == "EUROPE"]
pdat$country <- factor(pdat$country, levels = pdat$country)

ggplot(pdat, aes(x = country, y = catf, fill = EU)) +
  geom_col(show.legend = F) + 
  scale_fill_gdocs() +
  scale_x_discrete(name = "") +
  scale_y_continuous(name = "Cannabis-attributable treatment fraction (%)", labels = scales::percent) + 
  coord_flip() + 
  theme(legend.position = "bottom")

ggsave(paste0("figures/",DATE,"_F1.png"), width = 6, height = 8)  
ggsave(paste0("figures/",DATE,"_F1.pdf"), width = 6, height = 8)  

pdat[year != 2021]
pdat[catf<.1]
pdat[catf>.5]

# FIGURE 2: TUR by country
# ________________________

pdat <- copy(dat.tur[year == last,.(country,year,pm.daily,tdi,pop,tur)])
add <- pdat[, .(country = "EUROPE", year = 2020,
                tdi = sum(tdi), 
                pm.daily = wtd.mean(pm.daily,pop),
                pop = sum(pop))]
add[, tur := (tdi / (pm.daily*pop))*100]
pdat <- rbind(pdat,add)[order(tur)]
pdat[, EU := country == "EUROPE"]
pdat$country <- factor(pdat$country, levels = pdat$country)

ggplot(pdat, aes(x = country, y = tur, fill = EU)) +
  geom_col(show.legend = F) + 
  scale_fill_gdocs() +
  scale_x_discrete(name = "") +
  scale_y_continuous(name = "Treatment-User-Ratio\n(number of treatment entrants for cannabis per 100 (near) daily users)") + 
  coord_flip() + 
  theme(legend.position = "bottom")

ggsave(paste0("figures/",DATE,"_F2.png"), width = 8, height = 6)
ggsave(paste0("figures/",DATE,"_F2.pdf"), width = 8, height = 6)

pdat[EU == T, pop*pm.daily]
pdat[, unique(country)]
pdat[,summary(year)]
pdat[country == "EUROPE"] # 132,473 cannabis admissions ; 1.3% prevalence and 321666373*0.01342214 = 4,317,451 people in need
pdat[tur == min(tur)]
pdat[tur == max(26)]

# FIGURE 3: TUR trend plot
# ________________________

pdat <- copy(dat.tur)[year.one == F,.(country,year,first,last,pm.daily,pop,tdi,tur)][order(country,year)]
pdat[, tur.change := c(0,diff(tur)), by = country]
add <- copy(unique(pdat[,.(country,mark = ifelse(tur.change > 0, "Increasing TUR (trend: right)",
                                                 ifelse(tur.change < 0, "Decreasing TUR (trend: left)", NA)))]))[!is.na(mark)]
pdat <- merge(pdat,add, by = "country")

ggplot(pdat, aes(x = tur, y = pm.daily)) +
  facet_grid(. ~ mark) +
  geom_point() +
  geom_path(aes(group = country),
            arrow = arrow(length = unit(0.15, "cm"))) + 
  scale_color_solarized(name = "") + 
  scale_x_continuous(name = "Treatment-User-Ratio\n(number of treatment entrants for cannabis per 100 (near) daily users)") +
  scale_y_continuous(name = "% (near) daily users in 15-64 year olds", labels = scales::percent)

ggsave(paste0("figures/",DATE,"_F3.png"), width = 8, height = 4)
ggsave(paste0("figures/",DATE,"_F3.pdf"), width = 8, height = 4)

pdat[mark %like% "Decreas"]
pdat[mark %like% "Decreas",(unique(country))]
pdat[mark %like% "Increas"]
pdat[, unique(country)]
pdat[year == first, summary(year)]
pdat[year == last, summary(year)]


#	=================================================================================================================================================================
#	=================================================================================================================================================================
#	=================================================================================================================================================================

#	Supplement:
#	.....................

# Supplementary Table 1:
# ________________________

app.tab.dat <- copy(data[!is.na(catf) & sex == "total"])
app.tab.dat[!is.na(catf), catf.max := max(year), by = country]
app.tab.dat[!is.na(tur), tur.max := max(year), by = country]
app.tab.dat[, no.tur := sum(is.na(tur)) == .N, by = country]
out <- app.tab.dat[(no.tur == F & year == tur.max) | 
                     (no.tur == T & year == catf.max)]

write.xlsx(out[,.(country,year,admissions_any.drug,admissions_cannabis,catf,
                  pm.daily.prop = pm.daily,pm.daily.n = pm.daily * pop,tur)], paste0("tables/",DATE,"_SUPP_T1.xlsx"))
unique(dat.catf$country)

# Supplementary Figure 1:
# ________________________

# country trends:

pdat <- copy(data[sex == "total" & !is.na(admissions_any.drug) & !is.na(admissions_cannabis),.(country,year,any = admissions_any.drug, cannabis = admissions_cannabis)])
pdat <- melt(pdat, id.vars = c("country","year"))
pdat[, year.min := min(year), by = country]
pdat$ref <- NA_real_
pdat[year == year.min, ref := value]
pdat[, ref := mean(ref, na.rm = T), by = .(country,variable)]
pdat[, change := value/ref-1]

ggplot(pdat, aes(x = year, y = change, color = variable)) +
  facet_wrap(country ~ ., nrow = 5, scales = "free_y") +
  geom_point(shape = 21 ) +
  geom_path(arrow = arrow(length = unit(0.15, "cm"))) + 
  scale_color_solarized(name = "") + 
  scale_x_continuous(name = "Year", breaks = c(2010, 2015, 2020)) +
  scale_y_continuous(name = "change relative to first data year", labels = scales::percent) + 
  theme(legend.position = "bottom") + 
  guides(color = guide_legend(nrow=1,byrow=TRUE))

ggsave(paste0("figures/",DATE,"_SF1.png"), width = 12, height = 8)


# Supplementary Figure 2: Referral current
# ________________________

dat.referal[def == "cannabis" & referral == "legal"]
dat.referal[, .N, by = country]
dat.referal[, year.max := max(year), by = country]

pdat <- copy(dat.referal[year == year.max & def == "cannabis",.(loc = paste0(country," (",year,")"),refer=referral,value)])
pdat <- merge(pdat[refer == "total",.(loc,total = value)],
              pdat[refer != "total",.(loc,refer,value)], by = "loc")

pdat[, prop:=value/total]

pdat$refer <- factor(pdat$refer, levels = c("Other","unknown","Educational services",
                                            "Other drug treatment centre","Other health/social service",
                                            "General practitioner","legal",
                                            "Self-referral +"))

loc.order <- pdat[refer == "Self-referral +"][order(prop)]$loc
pdat$loc <- factor(pdat$loc, loc.order)
pdat <- pdat[!is.na(prop)]

ggplot(pdat, aes(x = loc, y = prop, fill = refer)) +
  geom_col(position = position_stack()) + 
  scale_fill_solarized(name = "") +
  scale_x_discrete()+
  scale_y_continuous(name = "", labels = scales::percent) + 
  theme(legend.position = "bottom") + 
  guides(fill = guide_legend(nrow=4,byrow=TRUE,reverse=T)) + 
  coord_flip()

ggsave(paste0("figures/",DATE,"_SF2.png"), width = 8, height = 10)

rm(pdat)

# Supplementary Figure 3: Referral trend
# ________________________

pdat <- copy(dat.referal[referral %in% c("total","legal") & year >= 2013,
                         .(country,year,def,referral,value)])
pdat <- dcast(pdat, country + year + def ~ referral)
add   <- pdat[,.(country = "EUROPE", 
                 legal = sum(legal),
                 total = sum(total)), by = .(year,def)]
pdat <- rbind(pdat, add)

pdat[, prop:=legal/total]

pdat <- pdat[order(country,year)]
pdat[, country := ifelse(country == "United Kingdom", "United\nKingdom", country)]
pdat$country  <- factor(pdat$country)

ggplot(pdat, aes(x = year, y = prop, color = def)) +
  facet_wrap(country ~ ., nrow = 5, scales = "free_y") +
  geom_point(shape = 21) + 
  geom_path(arrow = arrow(length = unit(0.15, "cm"))) + 
  scale_color_solarized(name = "") +
  scale_x_continuous("Year", breaks = c(2014,2017, 2020)) +
  scale_y_continuous(name = "Proportion of legal referrals", labels = scales::percent) + 
  theme(legend.position = "bottom") + 
  guides(color = guide_legend(nrow=1,byrow=TRUE))

ggsave(paste0("figures/",DATE,"_SF3.png"), width = 12, height = 8)

pdat[country == "Portugal" & def == "cannabis"]
pdat[country == "EUROPE" & def == "cannabis"]

rm(pdat, add)


#	=================================================================================================================================================================
#	=================================================================================================================================================================
#	=================================================================================================================================================================

#	referal:
#	.....................

dat.referal[def == "cannabis" & referral == "legal"]
dat.referal[def == "cannabis" & referral == "legal", sum(value, na.rm = T)] / 
  dat.referal[def == "cannabis" & referral == "total", sum(value, na.rm = T)]  # 25.7%

dat.referal[def == "all.drugs" & referral == "legal", sum(value, na.rm = T)] / 
  dat.referal[def == "all.drugs" & referral == "total", sum(value, na.rm = T)] # 14.8%


#	synthetic cannabinoids:
#	.....................

# from TDI table 2088
synth <- c("country syn
Belgium 0
Bulgaria 18
Croatia 10
Cyprus 3
Estonia 1
Finland 0
Greece 41
Hungary 0
Latvia 4
Malta 47
Poland 13
Portugal 7
Romania 3
Slovenia 0
Türkiye 538")

synth <- data.table(read.table(header = T, text = synth))
synth <- merge(synth, data[year == 2021 & sex == "total", .(country,can = admissions_cannabis)])
summary(synth[, syn / can])
sum(synth$syn) # 685
sum(synth$can) # 14777
sum(synth$syn) / sum(synth$can) # 4.6%
synth[syn / can >0.05,]


